@@ -269,11 +269,12 @@ class Haplotypes(SeqqlOperator):
 class Haplotype(SeqqlOperator):
     def __init__(self, key, entries):
         super(Haplotype, self).__init__({})
-        for key in entries:
-            if key in ["af", "score"]:
-                self._entries[key] = entries[key]
-            else:
-                self._entries[key] = Variant(key, entries[key])
+        if entries:
+            for key in entries:
+                if key in ["af", "score"]:
+                    self._entries[key] = entries[key]
+                else:
+                    self._entries[key] = Variant(key, entries[key])
         self.id = key
 
     def compute_genotypes(self, data_accessor: DataAccessor, genotypes: dict):
